@@ -17,7 +17,6 @@
 
 #include <cstddef>
 #include <string>
-#include "xtl/xvariant.hpp"
 #include "nlohmann/json.hpp"
 
 namespace xtl
@@ -82,17 +81,4 @@ namespace xtl
     }
 }
 
-// overloading in the mpark namespace because `xtl::variant` is just a typedef on `mpark::variant`
-namespace mpark
-{
-    template <class... Ts>
-    void to_json(nlohmann::json& j, const xtl::variant<Ts...>& data) {
-        xtl::visit
-        (
-            [&j] (const auto & arg) { j = arg; },
-            data
-        );
-    }
-}
-
 #endif
